Metrics
=======
.. automodapi:: pykeen.metrics
    :no-heading:
    :inherited-members:
    :headings: --

.. automodapi:: pykeen.metrics.ranking
    :no-heading:
    :inherited-members:
    :headings: --
